@@ -1,4 +1,10 @@
 use crate::query::Query;
+use inflector::cases::camelcase::to_camel_case;
+use inflector::cases::kebabcase::to_kebab_case;
+use inflector::cases::pascalcase::to_pascal_case;
+use inflector::cases::screamingsnakecase::to_screaming_snake_case;
+use inflector::cases::snakecase::to_snake_case;
+use inflector::cases::traincase::to_train_case;
 
 use regex::Regex;
 
@@ -11,7 +17,7 @@ use regex::Regex;
 /// use ruplacer::{Query, replace};
 ///
 /// let input = "this is some old text";
-/// let query = Query::substring("old", "new");
+/// let query = Query::simple("old", "new");
 /// let replacement = replace(input, &query).unwrap();
 /// let output = replacement.output();
 /// assert_eq!(output, "this is some new text");
@@ -145,19 +151,19 @@ impl<'a> Replacer for SubstringReplacer<'a> {
     }
 }
 
-struct SubvertReplacer<'a> {
+struct PreserveCaseReplacer<'a> {
     items: &'a [(String, String)],
 }
 
-impl<'a> SubvertReplacer<'a> {
+impl<'a> PreserveCaseReplacer<'a> {
     fn new(items: &'a [(String, String)]) -> Self {
         Self { items }
     }
 }
 
-impl<'a> Replacer for SubvertReplacer<'a> {
+impl<'a> Replacer for PreserveCaseReplacer<'a> {
     fn replace(&self, buff: &str) -> Option<(usize, String, String)> {
-        // Note: replacing using subvert can get tricky
+        // Note: replacing using preserve_case can get tricky
         //
         // Let's say self.items contains
         //  [("old", "new"), ("Old", "New")]
@@ -219,7 +225,7 @@ impl<'a> Replacer for RegexReplacer<'a> {
 ///    - printing the patch
 fn get_fragments(input: &str, query: &Query) -> Fragments {
     match query {
-        Query::Substring(pattern, replacement) => {
+        Query::Simple(pattern, replacement) => {
             let finder = SubstringReplacer::new(pattern, replacement);
             get_fragments_with_finder(input, finder)
         }
@@ -227,8 +233,25 @@ fn get_fragments(input: &str, query: &Query) -> Fragments {
             let finder = RegexReplacer::new(regex, replacement);
             get_fragments_with_finder(input, finder)
         }
-        Query::Subvert(items) => {
-            let finder = SubvertReplacer::new(items);
+        Query::PreserveCase(pattern, replacement) => {
+            fn to_ada_case(input: &str) -> String {
+                to_train_case(input).replace('-', "_")
+            }
+
+            let mut items = vec![];
+            for function in &[
+                to_ada_case,
+                to_camel_case,
+                to_kebab_case,
+                to_pascal_case,
+                to_screaming_snake_case,
+                to_snake_case,
+                to_train_case,
+            ] {
+                items.push((function(pattern), function(replacement)));
+            }
+
+            let finder = PreserveCaseReplacer::new(&items);
             get_fragments_with_finder(input, finder)
         }
     }
@@ -290,11 +313,11 @@ mod tests {
     use regex::Regex;
 
     #[test]
-    fn test_substring_1() {
+    fn test_simple_1() {
         let input = "Mon thé c'est le meilleur des thés !";
         let pattern = "thé";
         let replacement = "café";
-        let query = Query::substring(pattern, replacement);
+        let query = Query::simple(pattern, replacement);
         let replacement = replace(input, &query).unwrap();
         assert_eq!(
             replacement.output(),
@@ -303,11 +326,11 @@ mod tests {
     }
 
     #[test]
-    fn test_substring_2() {
+    fn test_simple_2() {
         let input = "old old old";
         let pattern = "old";
         let replacement = "new";
-        let query = Query::substring(pattern, replacement);
+        let query = Query::simple(pattern, replacement);
         let replacement = replace(input, &query).unwrap();
         assert_eq!(replacement.output(), "new new new");
     }
@@ -319,18 +342,18 @@ mod tests {
         let input = "Top: old is nice";
         let pattern = "old";
         let replacement = "new";
-        let query = Query::substring(pattern, replacement);
+        let query = Query::simple(pattern, replacement);
         let replacement = replace(input, &query).unwrap();
         let console = Console::new();
         console.print_replacement("foo.txt:3 ", &replacement);
     }
 
     #[test]
-    fn test_subvert() {
+    fn test_preserve_case() {
         let input = "let foo_bar = FooBar::new();";
         let pattern = "foo_bar";
         let replacement = "spam_eggs";
-        let query = Query::subvert(pattern, replacement);
+        let query = Query::preserve_case(pattern, replacement);
         let replacement = replace(input, &query).unwrap();
         assert_eq!(replacement.output(), "let spam_eggs = SpamEggs::new();");
     }
